<?php

class CentralpayotpModuleFrontController extends ModuleFrontController {

  public $module;

  const VIEWS_TEMPLATE_FRONT = '/views/templates/front/';
  const CENTRALPAY = '_CENTRALPAY_';
  public function __construct() {
    $this->controller_type = 'modulefront'; //instead of standard controllers’ front

    $this->module = Module::getInstanceByName(Tools::getValue('module')); // an instance of the module is created
    if (!$this->module->active) {
      Tools::redirect('index');
    } //if the module is inactive, the user will be redirected to index.php

    $this->page_name = 'module-' . $this->module->name . '-' . Dispatcher::getInstance()
        ->getController(); //for example: module-belvg_storelocator-search

    parent::__construct();
  }


  /**
   * Assign module template
   *
   * @param string $template
   */
  public function setTemplate($template) {
    if (Tools::file_exists_cache(_PS_THEME_DIR_ . 'modules/' . $this->module->name . '/' . $template)) {
      $this->template = _PS_THEME_DIR_ . 'modules/' . $this->module->name . '/' . $template;
    } //if the file with the template is located in the root directory
    elseif (Tools::file_exists_cache($this->getTemplatePath($template))) {
      $this->template = $this->getTemplatePath($template);
    } //otherwise file in  module_dir/views/templates/front/ should be used
    else {
      throw new PrestaShopException("Template '$template'' not found");
    } //if the file is not found, the exception will be thrown
  }

  /**
   * Get path to front office templates for the module
   *
   * @return string
   */
  public function getTemplatePath($template) {
    return _PS_MODULE_DIR_ . $this->module->name . self::VIEWS_TEMPLATE_FRONT . $template;
  }

  public function postProcess() {


  }

  /**
   * Assign template vars related to page content
   *
   * @see FrontController::initContent()
   */
  public function initContent() {

    $this->disableColumns();
    parent::initContent();
    $address = new Address($this->context->cart->id_address_delivery);



    $this->context->smarty->assign(
      [
        'PaRes' => Tools::getValue('PaRes'),
        'email' => $this->context->customer->email,
        'phone' => $address->phone,
        'provider' =>  Configuration::get(self::CENTRALPAY . 'PROVIDER')

      ]
    );

    return $this->setTemplate('otp.tpl');

  }


  protected function getModuleDir($data = NULL) {
    $path = _PS_MODULE_DIR_ . $this->module->name . self::VIEWS_TEMPLATE_FRONT ;
    if (!is_null($data)) {
      return _PS_MODULE_DIR_ . $this->module->name . self::VIEWS_TEMPLATE_FRONT  . $data . '/';
    }

    if (!is_null($data)) {
      throw new PrestaShopExceptionCore('Template not mapped');
    }

    return $path;
  }

  protected function disableColumns() {
    $this->display_column_left = FALSE;
    $this->display_column_right = FALSE;
    $this->display_footer = TRUE;
    $this->display_header = TRUE;
  }


}